@@ -169,8 +169,10 @@ echebin <-
   if(n.sim != 0){
     cat(paste("\n Monte Carlo rank ........: ", p_rank[1], "/", (n.sim + 1 - length(monte_lost)), "", sep=""))
     cat(paste("\n P-value .................: ", round(p_rank[1]/(n.sim + 1 - length(monte_lost)), digits=nchar(as.character(n.sim))+1), "", sep=""))
-    MLC <- c(MLC, list(p = p_rank[1]/(n.sim+1)))
+    MLC <- c(MLC, list(p = p_rank[1]/(n.sim + 1)))
   }
+  else MLC <- c(MLC, list(p = NA))
+
   cat("\n\n")
   clusters <- MLC
 
@@ -215,8 +217,10 @@ echebin <-
           cat(paste("\n Monte Carlo rank ........: ", p_rank[i], "/", (n.sim + 1 - length(monte_lost)), "", sep=""))
           cat(paste("\n P-value .................: ", round(p_rank[i]/(n.sim + 1 - length(monte_lost)), digits = nchar(as.character(n.sim))+1), "", sep=""))
         }
-        secondC <- c(secondC, list(p = p_rank[i]/(n.sim+1)))
+        secondC <- c(secondC, list(p = p_rank[i]/(n.sim + 1)))
       }
+      else secondC <- c(secondC, list(p = NA))
+
       if(i == 2) clusters <- list(clusters, secondC)
       else clusters[[i]] <- secondC
       if(cluster.info) cat("\n\n")
@@ -235,7 +239,8 @@ echebin <-
         cas_inZ <- sum(cas[cluster_reg[i,]], na.rm = TRUE)
         ex_inZ <- sum(pop[cluster_reg[i,]]*casg/popg, na.rm = TRUE)
         secondC <- c(secondC, list(cas_inZ = cas_inZ, ex_inZ = ex_inZ, LLR = cluster_log.lambda[i]))
-        if(n.sim != 0) secondC <- c(secondC, list(p=p_rank[i]/(n.sim + 1 - length(monte_lost))))
+        if(n.sim != 0) secondC <- c(secondC, list(p = p_rank[i]/(n.sim + 1 - length(monte_lost))))
+        else secondC <- c(secondC, list(p = NA))
         clusters[[i]] <- secondC
       }
     }
